text_form_field_flutter library

Classes

TextFormFieldFlutter
A highly customizable text form field that supports various styling options and validation features
TextFormFieldTheme
Theme configuration for FlutterTextFormField

Enums

LabelBehaviorStyles
Defines the behavior styles for the label in the text field